@@ -17,7 +17,7 @@ class Info:
     def __repr__(self):
         spec = inspect.getfullargspec(self.__init__)
         args = ", ".join(repr(getattr(self, x)) for x in spec.args[1:])
-        return "%s(%s)" % (self.__class__.__name__, args)
+        return f"{self.__class__.__name__}({args})"
 
     @classmethod
     def filter_parts(cls: Type[T], part_info: PartInfo) -> Dict[str, List[T]]:
@@ -77,9 +77,8 @@ class Info:
         filtered: List[T] = cls.filter_values(part_info)
         if len(filtered) != 1:
             if error_msg is None:
-                error_msg = "Expected a single %s, got %s of them" % (
-                    cls.__name__,
-                    len(filtered),
+                error_msg = (
+                    f"Expected a single {cls.__name__}, got {len(filtered)} of them"
                 )
             raise BadValueError(error_msg)
         return filtered[0]
