@@ -51,7 +51,7 @@ class FieldRegistry:
             for (n, field, _, _) in fields:
                 if n == name:
                     return field
-        raise ValueError("No field named %s found" % (name,))
+        raise ValueError(f"No field named {name} found")
 
     def add_method_model(
         self,
@@ -69,16 +69,16 @@ class FieldRegistry:
             call_types = getattr(func, "call_types", {})
             context_anno: Anno = call_types.get("context", None)
             assert context_anno, (
-                "Func %s needs_context, but has no 'context' anno. Did "
-                "you forget the @add_call_types decorator?" % func
+                f"Func {func} needs_context, but has no 'context' anno. Did "
+                "you forget the @add_call_types decorator?"
             )
             assert list(call_types)[0] == "context", (
-                "Func %s needs_context, so 'context' needs to be the first "
-                "argument it takes" % func
+                f"Func {func} needs_context, so 'context' needs to be the first "
+                "argument it takes"
             )
             assert context_anno.typ is Context, (
-                "Func %s needs_context, but 'context' has type %s rather than"
-                "Context" % (func, context_anno.typ)
+                f"Func {func} needs_context, but 'context' has type "
+                f"{context_anno.type} rather than Context"
             )
             without = ("context",)
         else:
@@ -108,19 +108,14 @@ class FieldRegistry:
         writeable_func: Optional["Callable"] = None,
         needs_context: bool = False,
     ) -> None:
-        assert CAMEL_RE.match(name), "Field %r published by %s is not camelCase" % (
-            name,
-            owner,
-        )
+        assert CAMEL_RE.match(
+            name
+        ), f"Field {name!r} published by {owner} is not camelCase"
         for o, fields in self.fields.items():
             existing = [x for x in fields if x[0] == name]
             assert (
                 not existing
-            ), "Field %r published by %s would overwrite one made by %s" % (
-                name,
-                owner,
-                o,
-            )
+            ), f"Field {name!r} published by {owner} would overwrite one made by {o}"
         part_fields = self.fields.setdefault(owner, [])
         part_fields.append((name, model, cast(Callable, writeable_func), needs_context))
 
@@ -138,9 +133,9 @@ class InfoRegistry:
             callback = self._reportable_infos[typ]
         except KeyError:
             raise ValueError(
-                "Don't know how to report a %s, only %s\n"
+                f"Don't know how to report a {typ.__name__}, only "
+                f"{[x.__name__ for x in self._reportable_infos]}\n"
                 "Did you use the wrong type of Controller?"
-                % (typ.__name__, [x.__name__ for x in self._reportable_infos])
             )
         callback(reporter, info)
 
@@ -151,7 +146,7 @@ class Part(Hookable):
     def __init__(self, name: APartName) -> None:
         assert PART_NAME_RE.match(name), (
             "Expected Alphanumeric part name (dashes and underscores allowed)"
-            + " got %r" % name
+            + f" got {name!r}"
         )
         self.set_logger(part_name=name)
         self.name: str = name
