@@ -117,7 +117,7 @@ class StatefulController(BasicController):
         try:
             super().check_field_writeable(field)
         except NotWriteableError as e:
-            msg = "%s, maybe because Block state = %s" % (e, self.state.value)
+            msg = f"{e}, maybe because Block state = {self.state.value}"
             raise NotWriteableError(msg)
 
     def transition(self, state, message=""):
@@ -147,9 +147,7 @@ class StatefulController(BasicController):
                 for child, writeable in self._children_writeable[state].items():
                     child.meta.set_writeable(writeable)
             else:
-                raise TypeError(
-                    "Cannot transition from %s to %s" % (initial_state, state)
-                )
+                raise TypeError(f"Cannot transition from {initial_state} to {state}")
 
     def try_stateful_function(self, start_state, end_state, func, *args, **kwargs):
         try:
