@@ -25,7 +25,6 @@ AMri = builtin.controllers.AMri
 AConfigDir = builtin.controllers.AConfigDir
 ATemplateDesigns = builtin.controllers.ATemplateDesigns
 AInitialDesign = builtin.controllers.AInitialDesign
-AUseGit = builtin.controllers.AUseGit
 ADescription = builtin.controllers.ADescription
 
 
@@ -44,7 +43,6 @@ class PandAManagerController(builtin.controllers.ManagerController):
         poll_period: APollPeriod = 0.1,
         template_designs: ATemplateDesigns = "",
         initial_design: AInitialDesign = "",
-        use_git: AUseGit = True,
         description: ADescription = "",
     ) -> None:
         super().__init__(
@@ -52,7 +50,6 @@ class PandAManagerController(builtin.controllers.ManagerController):
             config_dir=config_dir,
             template_designs=template_designs,
             initial_design=initial_design,
-            use_git=use_git,
             description=description,
         )
         self._poll_period = poll_period
@@ -172,7 +169,7 @@ class PandAManagerController(builtin.controllers.ManagerController):
                 # Look through the BlockData for things we are interested in
                 for field_name, field_data in block_data.fields.items():
                     if field_data.field_type == "pos_out":
-                        pos_names.append("%s.%s" % (block_name, field_name))
+                        pos_names.append(f"{block_name}.{field_name}")
 
                 # Make the child controller and add it to the process
                 controller, child_part = self._make_child_block(block_name, block_data)
@@ -195,7 +192,7 @@ class PandAManagerController(builtin.controllers.ManagerController):
         self._bus_fields = set(pos_names)
         for pos_name in pos_names:
             for suffix in ("CAPTURE", "UNITS", "SCALE", "OFFSET"):
-                self._bus_fields.add("%s.%s" % (pos_name, suffix))
+                self._bus_fields.add(f"{pos_name}.{suffix}")
         # Handle the bit_outs, keeping a list for toggling and adding them
         # to the set of things that the busses need
         self._bit_outs = {k: 0 for k in self.busses.bits.value.name}
@@ -207,9 +204,9 @@ class PandAManagerController(builtin.controllers.ManagerController):
         self.handle_changes(self._client.get_changes())
         # Then once more to let bit_outs toggle back
         self.handle_changes(())
-        assert not self._bit_out_changes, (
-            "There are still bit_out changes %s" % self._bit_out_changes
-        )
+        assert (
+            not self._bit_out_changes
+        ), f"There are still bit_out changes {self._bit_out_changes}"
 
     def _make_busses(self) -> PandABussesPart:
         return PandABussesPart("busses", self._client)
