@@ -35,7 +35,7 @@ class CSSourcePortsPart(Part):
         for k in CS_AXIS_NAMES + ["I"]:
             # Note no widget tag as we don't want it on the properties pane,
             # just the layout view
-            v = StringMeta("Axis Source Port value %s" % k).create_attribute_model()
+            v = StringMeta(f"Axis Source Port value {k}").create_attribute_model()
             self.axis_attrs[k] = v
             registrar.add_attribute_model(k.lower(), v)
 
@@ -46,7 +46,7 @@ class CSSourcePortsPart(Part):
             # Add the Source Port tags
             old_tags = v.meta.tags
             new_tags = Port.MOTOR.with_source_port_tag(
-                old_tags, connected_value="%s,%s" % (value, k)
+                old_tags, connected_value=f"{value},{k}"
             )
             if old_tags != new_tags:
                 v.meta.set_tags(new_tags)
