@@ -44,7 +44,7 @@ class ConfigureParams(Serializable):
         generator: AGenerator,
         axesToMove: UAxesToMove = None,
         breakpoints: ABreakpoints = None,
-        **kwargs: Any
+        **kwargs: Any,
     ) -> None:
         if kwargs:
             # Got some additional args to report
@@ -84,7 +84,7 @@ class PointGeneratorMeta(VMeta):
         elif isinstance(value, dict):
             return CompoundGenerator.from_dict(value)
         else:
-            raise TypeError("Value %s must be a Generator object or dictionary" % value)
+            raise TypeError(f"Value {value} must be a Generator object or dictionary")
 
 
 with Anno("Dataset names"):
